package com.hw.ems.record.service;

import java.util.List;

import com.hw.ems.record.domain.RecordAlarmRule;

/**
 * 异常告警规则Service接口
 *
 * @author hw
 * @date 2023-04-21
 */
public interface IRecordAlarmRuleService {
    /**
     * 查询异常告警规则
     *
     * @param objId 异常告警规则主键
     * @return 异常告警规则
     */
    public RecordAlarmRule selectRecordAlarmRuleByObjId(Long objId);

    /**
     * 查询异常告警规则列表
     *
     * @param recordAlarmRule 异常告警规则
     * @return 异常告警规则集合
     */
    public List<RecordAlarmRule> selectRecordAlarmRuleList(RecordAlarmRule recordAlarmRule);

    /**
     * 新增异常告警规则
     *
     * @param recordAlarmRule 异常告警规则
     * @return 结果
     */
    public int insertRecordAlarmRule(RecordAlarmRule recordAlarmRule);

    /**
     * 修改异常告警规则
     *
     * @param recordAlarmRule 异常告警规则
     * @return 结果
     */
    public int updateRecordAlarmRule(RecordAlarmRule recordAlarmRule);

    /**
     * 批量删除异常告警规则
     *
     * @param objIds 需要删除的异常告警规则主键集合
     * @return 结果
     */
    public int deleteRecordAlarmRuleByObjIds(Long[] objIds);

    /**
     * 删除异常告警规则信息
     *
     * @param objId 异常告警规则主键
     * @return 结果
     */
    public int deleteRecordAlarmRuleByObjId(Long objId);
}
